powered by
After the heatmap was drawn in a screen device such as X11, windows and quartz it can be zoomed by using the mouse.
zoom_heatmap(dl, ...)
(list). The "display list": A list with all parameters needed for plotting the heatmap.
list
(list). Additional parameters passed to draw_heatmap (and eventually to plot).
draw_heatmap
plot
Invisibly returns a list with graphical parameters but is mainly called for its side-effect of drawing a zoomed plot.
locator